"""Constants for Habiticalib."""

__version__ = "0.3.3"

DEFAULT_URL = "https://habitica.com/"
ASSETS_URL = "https://habitica-assets.s3.amazonaws.com/mobileApp/images/"

DEVELOPER_ID = "4c4ca53f-c059-4ffa-966e-9d29dd405daf"

BACKER_ONLY_GEAR = {
    "armor_special_ks2019": "BackerOnly-Equip-MythicGryphonArmor.gif",
    "eyewear_special_ks2019": "BackerOnly-Equip-MythicGryphonVisor.gif",
    "head_special_ks2019": "BackerOnly-Equip-MythicGryphonHelm.gif",
    "shield_special_ks2019": "BackerOnly-Equip-MythicGryphonShield.gif",
    "weapon_special_ks2019": "BackerOnly-Equip-MythicGryphonGlaive.gif",
}

PAGE_LIMIT = 60
